| Title: | Yeo 2011 Atlas for the 'ggsegverse' Ecosystem |
|---|---|
| Description: | Yeo 2011 resting-state network atlases for the 'ggseg' ecosystem. Provides 'ggseg_atlas' objects with 2D polygon geometry for use with 'ggseg'. Includes both 7-network and 17-network parcellations. |
| Authors: | Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>), Didac Vidal-PiƱeiro [aut] (ORCID: <https://orcid.org/0000-0001-9997-9156>) |
| Maintainer: | Athanasia Mo Mowinckel <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2.0.2 |
| Built: | 2026-05-23 09:17:30 UTC |
| Source: | https://github.com/ggsegverse/ggsegYeo2011 |
Brain atlas for the Yeo et al. (2011) 17-network resting-state cortical
parcellation. Contains 2D polygon geometry for ggseg::geom_brain().
yeo17()yeo17()
A ggseg.formats::ggseg_atlas object (cortical).
Yeo BTT, Krienen FM, Sepulcre J, et al. (2011). The organization of the human cerebral cortex estimated by intrinsic functional connectivity. Journal of Neurophysiology, 106(3):1125-1165. doi:10.1152/jn.00338.2011
Other ggseg_atlases:
yeo7()
Other cortical_atlases:
yeo7()
yeo17() plot(yeo17())yeo17() plot(yeo17())
Brain atlas for the Yeo et al. (2011) 7-network resting-state cortical
parcellation. Contains 2D polygon geometry for ggseg::geom_brain().
yeo7()yeo7()
A ggseg.formats::ggseg_atlas object (cortical).
Yeo BTT, Krienen FM, Sepulcre J, et al. (2011). The organization of the human cerebral cortex estimated by intrinsic functional connectivity. Journal of Neurophysiology, 106(3):1125-1165. doi:10.1152/jn.00338.2011
Other ggseg_atlases:
yeo17()
Other cortical_atlases:
yeo17()
yeo7() plot(yeo7())yeo7() plot(yeo7())